<?php

/**
 * @file
 * Part of the "Better Form Errors" module that will be included for
 * displaying help.
 */

/**
 * Implemens hook_help().
 *
 * https://api.drupal.org/api/drupal/modules!system!system.api.php/function/hook_help/7
 */
function better_form_errors_help($path, $arg) {
  $readme = 'README.txt';
  $readme_menu_item = 'admin/better_form_errors/readme';
  switch ($path) {

    case 'admin/help#better_form_errors':
      $link_module = l(
        BETTER_FORM_ERRORS_MODULE_FULLNAME,
        BETTER_FORM_ERRORS_MODULE_HOMEPAGE,
        array(
          'attributes' => array(
            'target' => '_blank',
            'title' => t('Homepage of') . ' "' . BETTER_FORM_ERRORS_MODULE_FULLNAME . '" ' . t('module'),
          ),
        )
      );
      $link_author = l(
        BETTER_FORM_ERRORS_AUTHOR_NAME,
        BETTER_FORM_ERRORS_AUTHOR_HOMEPAGE,
        array(
          'attributes' => array(
            'target' => '_blank',
            'title' => t('Author of') . ' "' . BETTER_FORM_ERRORS_MODULE_FULLNAME . '" ' . t('module'),
          ),
        )
      );

      $link_readme = l(
        $readme,
        $readme_menu_item,
        array(
          'attributes' => array(
            'title' => $readme . ' ' . t('of') . ' "' . BETTER_FORM_ERRORS_MODULE_FULLNAME . '" ' . t('module'),
          ),
        )
      );

      $placeholders = array(
        '!link_module' => $link_module,
        '!link_author' => $link_author,
        '!link_readme' => $link_readme,
      );

      $return = "\n" . '<p>' . t(
        "Welcome to the Help page of Drupal's !link_module module, developed by !link_author.",
        $placeholders
      ) . '</p>';
      $return .= '<p>' . t(
        "Complete documentation is available in the module's !link_readme file.",
        $placeholders
      ) . '</p>';
      return $return;

    case $readme_menu_item:
      $path_readme = BETTER_FORM_ERRORS_MY_PATH . $readme;
      if (is_readable($path_readme)) {
        $contents_readme = file_get_contents($path_readme);
        if (!drupal_strlen($contents_readme)) {
          $contents_readme = t('Error: File could not be read!');
        }
      }
      else {
        $contents_readme = t('Error: File is not readable!');
      }
      drupal_add_css(BETTER_FORM_ERRORS_MY_URL . 'css/better_form_errors.help.css', array(
        'media' => 'screen, print',
        )
      );
      $return = "\n" . '<p><pre class="pre-readme">' . check_plain($contents_readme) . '</pre></p>';
      return $return;
  }
}
